package fr.uca.iut.clfreville2.teaiswarm

import android.content.Intent
import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import androidx.lifecycle.lifecycleScope
import androidx.recyclerview.widget.RecyclerView
import fr.uca.iut.clfreville2.teaiswarm.model.Repository
import fr.uca.iut.clfreville2.teaiswarm.network.GiteaService
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch

const val REPOSITORY_OWNER = "repository_owner"
const val REPOSITORY_NAME = "repository_name"

class MainActivity : AppCompatActivity() {

    private val service = GiteaService()
    private lateinit var repositories: RecyclerView

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)
        repositories = findViewById(R.id.repositories_view)
        lifecycleScope.launch(Dispatchers.IO) {
            val repos = service.listActiveRepositories("clement.freville2", 1)
            lifecycleScope.launch {
                repositories.adapter = RepositoryListAdapter(repos) { repo ->
                    adapterOnClick(repo)
                }
            }
        }
    }

    private fun adapterOnClick(repository: Repository) {
        val intent = Intent(this, RepositoryDetailActivity()::class.java)
        intent.putExtra(REPOSITORY_OWNER, repository.owner.login)
        intent.putExtra(REPOSITORY_NAME, repository.name)
        startActivity(intent)
    }
}