package fr.uca.iut.clfreville2.teaiswarm.network

import com.squareup.moshi.Moshi
import com.squareup.moshi.kotlin.reflect.KotlinJsonAdapterFactory

import fr.uca.iut.clfreville2.teaiswarm.model.Repository
import fr.uca.iut.clfreville2.teaiswarm.model.RepositoryIdentifiable
import fr.uca.iut.clfreville2.teaiswarm.model.VersionedFile
import okhttp3.OkHttpClient
import retrofit2.Retrofit
import retrofit2.converter.moshi.MoshiConverterFactory
import retrofit2.http.GET
import retrofit2.http.Path
import retrofit2.http.Query

interface GiteaApiService {

    @GET("users/{username}/repos")
    suspend fun listActiveRepositories(@Path("username") username: String, @Query("page") page: Int): List<Repository>

    @GET("repos/{owner}/{repo}/contents/{filePath}")
    suspend fun listFileContents(@Path("owner") owner: String, @Path("repo") repo: String, @Path("filePath") filePath: String): List<VersionedFile>
}

class GiteaService(private val handle: GiteaApiService) : RepositoryService {

    constructor() : this(createRetrofit().create(GiteaApiService::class.java))

    override suspend fun listActiveRepositories(username: String, page: Int): List<Repository> =
        handle.listActiveRepositories(username, page)

    override suspend fun listFileContents(repository: RepositoryIdentifiable, filePath: String): List<VersionedFile> =
        handle.listFileContents(repository.identifier.owner, repository.identifier.name, filePath)
}

private const val CODEFIRST_API_BASE = "https://codefirst.iut.uca.fr/git/api/v1/"

private val httpClient = OkHttpClient()

private fun createRetrofit(): Retrofit =
    Retrofit.Builder()
        .baseUrl(CODEFIRST_API_BASE)
        .addConverterFactory(MoshiConverterFactory.create(
            Moshi.Builder()
                .add(KotlinJsonAdapterFactory())
                .build()))
        .client(httpClient)
        .build()
